@@ -6,7 +6,10 @@
 #'  before pushing them to your code base. Such automatic
 #'  chunk labelling is best paired with version control.
 #'
-#' @param path Path to file
+#' @returns Always returns TRUE invisibly. Called for side effects.
+#'
+#' @template path
+#' @template unname
 #'
 #' @export
 #'
@@ -20,7 +23,7 @@
 #' file.edit(temp_file_path)
 #' }
 #' file.remove(temp_file_path)
-name_chunks <- function(path){
+name_chunks <- function(path, unname = FALSE){
   # read the whole file
   lines <- readLines(path)
 
@@ -29,7 +32,12 @@ name_chunks <- function(path){
 
   # early exit if no chunk
   if(is.null(chunk_headers_info)){
-    return(invisible("TRUE"))
+    return(invisible(TRUE))
+  }
+
+  # check if a force-unname should be done
+  if (isTRUE(unname)) {
+    unname_chunks(path)
   }
 
   # filter the one corresponding to unnamed chunks
@@ -85,16 +93,19 @@ Maybe namer::unname_chunks before running name_chunks.")
     # save file
     writeLines(lines, path)
 }
-  return(invisible("TRUE"))
+  return(invisible(TRUE))
 }
 
 #' @title  Name chunks of all Rmds in a dir
 #'
 #' @description  Name unnamed chunks in a dir using the filenames with extension stripped as basis.
 #'
+#' @returns Always returns TRUE invisibly. Called for side effects.
+#'
 #' @inherit name_chunks details
 #'
-#' @param dir Path to folder
+#' @template dir
+#' @template unname
 #'
 #' @export
 #'
@@ -114,9 +125,19 @@ Maybe namer::unname_chunks before running name_chunks.")
 #' file.edit(file.path(temp_dir,
 #'                    "examples", "example1.Rmd"))
 #' }
-name_dir_chunks <- function(dir){
+name_dir_chunks <- function(dir, unname = FALSE){
+
+  if (isTRUE(unname)) {
+    cli::cat_rule("Unnaming all chunks")
+    unname_dir_chunks(dir)
+  }
+
+  cli::cat_rule("Naming all chunks")
+
   rmds <- fs::dir_ls(dir, regexp = "*.[Rr]md")
   purrr::walk(rmds, chatty_name_chunks)
+
+  return(invisible(TRUE))
 }
 
 chatty_name_chunks <- function(path){
